@@ -31,6 +31,18 @@
  int firstVisChar = 0;	//which char is the first in input line? 
 			//(used when scrolling a long input)
 
+void uputchar(char *ch)
+{
+  static char c[5];
+  memset(c, 0, 5);
+  c[0] = ch[0];
+  if ((c[0] & mask[0]) == mask[0]) c[1] = ch[1];
+  if ((c[0] & mask[1]) == mask[1]) c[2] = ch[2];
+  if ((c[0] & mask[2]) == mask[2]) c[3] = ch[3];
+  c[4] = '0';
+  printf("%s", c);
+}
+
  
 /**************************************************************************
  * inputBoxI(): 
