@@ -145,7 +145,7 @@ int main(int argc, char **argv)
 	    || strcmp(argv[i], "-v")) 
     {
       //******Show version
-      printf("\nPrime version 1.0.\n");
+      printf("\nPrime version 1.1.\n");
     } 
     else if(strcmp(argv[i], "--export") == 0
 	    || strcmp(argv[i], "-e") == 0) 
@@ -210,7 +210,7 @@ int main(int argc, char **argv)
       if(!(log_file = fopen(log_file_name, "w"))) 
       {
 	printf("\nFatal error: couldn't open logfile 'Prime.log'.\n"
-	  "If you want to start Prime with no log, type './Prime --no-log'\n"
+	  "If you want to start Prime with no log, type './prime --no-log'\n"
 	  "Aborting.\n");
 	exit(1);
       }
@@ -220,7 +220,7 @@ int main(int argc, char **argv)
 	    || strcmp(argv[i], "-h") == 0) 
     {
       //******Show command line help
-      printf("Prime for GNU/Linux, Version 1.0\n"
+      printf("Prime for GNU/Linux, Version 1.1\n"
 	     "By Mohammed Isam, 2013, 2014\n"
 	     "Prime is a GNU software, as part of the GnuDOS package\n\n"
 	     "Prime is a file manager for the GNU/Linux console/xterm.\n"
@@ -263,7 +263,7 @@ int main(int argc, char **argv)
 	else 
 	{
 	    printf("Couldn't open logfile. If you want to start Prime with no \
-log, type './Prime --no-log'\n");
+log, type './prime --no-log'\n");
 	    exit(1);
 	}
       }
@@ -281,7 +281,7 @@ log, type './Prime --no-log'\n");
     strcat(log_file_name, "Prime.log");
     if(!(log_file = fopen(log_file_name, "w"))) {
       printf("\nFatal error: couldn't open logfile 'Prime.log'.\n"
-	  "If you want to start Prime with no log, type './Prime --no-log'\n"
+	  "If you want to start Prime with no log, type './prime --no-log'\n"
 	  "Aborting.\n");
       exit(1);
     }
@@ -291,6 +291,12 @@ log, type './Prime --no-log'\n");
  
  cwd = getcwd(NULL, 0);
  tm = time(NULL);
+ if(!log_file)
+	{
+	    printf("Couldn't open logfile. If you want to start Prime with no \
+log, type './prime --no-log'\n");
+	    exit(1);
+	}
  fprintf(log_file, "Starting Prime in: %s\n", cwd);
  fprintf(log_file, "System time and date: %s", ctime(&tm));
  fprintf(log_file, "Log_file: %s\n", log_file_name);
@@ -1361,8 +1367,9 @@ void init()
   editMenu[6] = "Find..     ^F";
   //4. Help Menu//
   helpMenu[0] = "View README    ";
-  helpMenu[1] = "Quick reference";
-  helpMenu[2] = "About Prime..    ";
+  helpMenu[1] = "GNU keybindings";
+  helpMenu[2] = "Quick reference";
+  helpMenu[3] = "About Prime..  ";
 
  int i;
   //set defaults for Dir view//
@@ -1463,6 +1470,7 @@ int read_config_file()
 	printf("Resetting configuration file.\n");
 	//exit(1);
 	write_config_file();
+	config_file = fopen(config_file_name, "r");
       }
 
       char buf[100];
